# PDF_analyzer

https://github.com/Veronica-gg/PDF_analyzer

PDF metadata analyzer and parser using [PDFx library](https://github.com/metachris/pdfx).

## Install

pip install -r requirements.txt

## Run

python process.py --pdf <file.pdf>

